@@ -1,7 +1,7 @@
-id = "fff074c3c0773879d2ccd8bed1043152668944a5"
-date = "2015-09-17 17:32:00 +0000"
+id = "fb530cfcc517687cb351bfdd9f4dbcf0ab8d3625"
+date = "2015-10-21 19:51:49 +0000"
 branch = "master"
-tag = "None"
+tag = "pylal-v0.9.0-v1"
 if tag == "None":
     tag = None
 author = "Kipp Cannon <kipp.cannon@ligo.org>"
@@ -10,11 +10,11 @@ committer = "Kipp Cannon <kipp.cannon@ligo.org>"
 status = "CLEAN: All modifications committed"
 version = id
 verbose_msg = """Branch: master
-Tag: None
-Id: fff074c3c0773879d2ccd8bed1043152668944a5
+Tag: pylal-v0.9.0-v1
+Id: fb530cfcc517687cb351bfdd9f4dbcf0ab8d3625
 
 Builder: Kipp Cannon <kipp.cannon@ligo.org>
-Build date: 2015-09-17 17:32:48 +0000
+Build date: 2015-10-21 19:53:11 +0000
 Repository status: CLEAN: All modifications committed"""
 
 import warnings
@@ -33,9 +33,9 @@ def check_match(foreign_id, onmismatch="raise"):
     """
     if onmismatch not in ("raise", "warn"):
         raise ValueError, onmismatch + " is an unrecognized value of onmismatch"
-    if foreign_id == "fff074c3c0773879d2ccd8bed1043152668944a5":
+    if foreign_id == "fb530cfcc517687cb351bfdd9f4dbcf0ab8d3625":
         return
-    msg = "Program id (fff074c3c0773879d2ccd8bed1043152668944a5) does not match given id (%s)." % foreign_id
+    msg = "Program id (fb530cfcc517687cb351bfdd9f4dbcf0ab8d3625) does not match given id (%s)." % foreign_id
     if onmismatch == "raise":
         raise VersionMismatchError, msg
 
