@@ -1,4 +1,4 @@
-# Copyright (C) 2007--2013  Kipp Cannon
+# Copyright (C) 2007--2014  Kipp Cannon
 #
 # This program is free software; you can redistribute it and/or modify it
 # under the terms of the GNU General Public License as published by the
@@ -164,7 +164,7 @@ WHERE
 
 def sngl_burst_veto_func(event, vetoseglists):
 	# return True if event should be *retained*
-	return event.ifo not in vetoseglists or event.get_peak() not in vetoseglists[event.ifo]
+	return event.ifo not in vetoseglists or event.peak not in vetoseglists[event.ifo]
 
 
 def ligolw_burca2(database, ln_likelihood_ratio, params_func, verbose = False, params_func_extra_args = ()):
